@@ -55,7 +55,7 @@ class FakeEnumAlt(fields.Enum):
     PLATYPUS = "platypus"
     AARDVARK = "aardvark"
 
-    ALL = (FROG, PLATYPUS, AARDVARK)
+    ALL = set([FROG, PLATYPUS, AARDVARK])
 
     def __init__(self, **kwargs):
         super(FakeEnumAlt, self).__init__(valid_values=FakeEnumAlt.ALL,
@@ -256,6 +256,10 @@ class TestBaseEnum(TestField):
         self.assertEqual(self.field.valid_values,
                          FakeEnum.ALL)
 
+    def test_valid_values_keeps_type(self):
+        self.assertIsInstance(self.field.valid_values, tuple)
+        self.assertIsInstance(FakeEnumAltField().valid_values, set)
+
 
 class TestEnum(TestField):
     def setUp(self):
